@@ -19,9 +19,9 @@
 #endif
 
 #define VIZIONSDK_VERSION_MAJOR 25
-#define VIZIONSDK_VERSION_MINOR 10
+#define VIZIONSDK_VERSION_MINOR 12
 #define VIZIONSDK_VERSION_PATCH 0
-#define VIZIONSDK_VERSION_BUILD 3
+#define VIZIONSDK_VERSION_BUILD 1
 
 // clang-format off
 #define VIZIONSDK_VERSION                 \
@@ -37,6 +37,7 @@
 #include "VxPublicTypes.hpp"
 
 class VxCamera;
+class VxRoute;
 
 void VIZIONSDK_API HelloVizionSDK(void);
 
@@ -152,5 +153,10 @@ int VIZIONSDK_API VxResetFrameCount(std::shared_ptr<VxCamera> vxcam);
 int VIZIONSDK_API VxExportSensorConfig(std::shared_ptr<VxCamera> vxcam, std::string cofigPath);
 int VIZIONSDK_API VxDecodeSensorConfig(std::string cofigPath, std::string jsonPath);
 
-/* Route Reset */
-int VIZIONSDK_API VxResetActiveRoutes();
\ No newline at end of file
+/* Route Setting */
+int VIZIONSDK_API VxResetActiveRoutes();
+std::shared_ptr<VxRoute> VIZIONSDK_API VxLoadRouteYaml(const std::string& yamlPath);
+int VIZIONSDK_API VxActivateYamlRoutes(std::shared_ptr<VxRoute> yamlRoutes);
+
+/* Sensor Work Mode */
+int VIZIONSDK_API VxGetSensorWorkMode(std::shared_ptr<VxCamera> vxcam, VX_SENSOR_MODE& mode);
\ No newline at end of file
